<div xmlns="http://www.w3.org/1999/xhtml"
       xmlns:py="http://genshi.edgewall.org/">
<table
       id="${id}" class="${css_class}">
    <thead py:if="columns">
        <tr>
            <th py:if="pks"/>
            <th py:for="i, col in enumerate(columns)" class="col_${i}">
            ${col.title}
            </th>
        </tr>
    </thead>
    <tbody>
        <tr py:for="i, row in enumerate(value)"
            class="${i%2 and 'odd' or 'even'}">
            <td py:if="pks">
<?python

pklist = ''
for pk in pks:
    pklist+=str(row[pk])
    pklist+='/'
pklist = pklist[:-1]
?>
       <div>
           <div>&nbsp;<a href="${pklist}/edit" style="text-decoration:None; color: #286571;">edit</a></div>
           <div>
              <form method="POST" action="${pklist}" class="button-to">
                 <input type="hidden" name="_method" value="DELETE" />
                 <input class="delete-button" onClick="return confirm('Are you sure you want to delete?');" value="delete" type="submit"
                    style="background: transparent; float:left; border:0; color: #286571; display: inline; margin: 0; padding: 0;"/>
              </form>
            </div>
        </div>
            </td>
            <td py:for="col in columns">${col.get_field(row, displays_on='genshi')}</td>
        </tr>
    </tbody>
</table>
    <py:if test="len(value) == 0">
      No Records Found.
    </py:if>
</div>